@@ -17,7 +17,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
-#include "config.h"
+#include <config.h>
 
 #include <string.h>
 #include <string.h>
@@ -44,6 +44,12 @@
 
 #define DELAYED_CALLBACK_DELAY (50)
 
+#if GLIB_CHECK_VERSION (2, 10, 0)
+#define I_(string) g_intern_static_string (string)
+#else
+#define I_(string) string
+#endif
+
 struct _AisleriotGame
 {
   GObject parent_instance;
@@ -531,7 +537,7 @@ cscmi_slot_set_cards (Slot *slot,
   aisleriot_game_slot_add_cards (game, slot, data, n_cards);
 }    
 
-static void
+static SCM
 cscmi_add_slot (SCM slot_data)
 {
   AisleriotGame *game = app_game;
@@ -540,9 +546,10 @@ cscmi_add_slot (SCM slot_data)
   gboolean expanded_right = FALSE;
   int expansion_depth = 0;
 
-  /* FIXMEchpe check whether this can happen; if it does, fix assumption that it doesn't in Board class. */
   if (game->state > GAME_BEGIN) {
-    g_warning ("Trying to add slot after game has started!\n");
+    return scm_throw (scm_from_locale_symbol ("game-started"),
+                      scm_cons (scm_from_locale_string ("Cannot add a new slot after the game has started."),
+                                SCM_EOL));
   }
 
 #ifdef HAVE_GUILE_1_8
@@ -588,6 +595,8 @@ cscmi_add_slot (SCM slot_data)
 
   /* this will update the slot length too */
   cscmi_slot_set_cards (slot, SCM_CADR (slot_data));
+
+  return SCM_EOL;
 }
 
 /* Scheme functions */
@@ -697,24 +706,6 @@ scm_set_statusbar_message (SCM message)
   return SCM_EOL;
 }
 
-static SCM
-scm_set_surface_layout (SCM surface)
-{
-  AisleriotGame *game = app_game;
-
-  if (surface != SCM_EOL) {
-    SCM list_el;
-
-    clear_slots (game, TRUE);
-
-    for (list_el = surface; list_el != SCM_EOL; list_el = SCM_CDR (list_el))
-      cscmi_add_slot (SCM_CAR (list_el));
-  }
-
-  return SCM_EOL;
-}
-
-
 static SCM
 scm_reset_surface (void)
 {
@@ -724,13 +715,6 @@ scm_reset_surface (void)
   return SCM_EOL;
 }
 
-static SCM
-ar_scm_add_slot (SCM slot)
-{
-  cscmi_add_slot (slot);
-  return SCM_EOL;
-}
-
 static SCM
 scm_set_slot_x_expansion (SCM scm_slot_id,
                           SCM new_exp_val)
@@ -995,9 +979,8 @@ cscm_init (void)
   scm_c_define_gsubr ("get-feature-word", 0, 0, 0, scm_get_feature_word);
   scm_c_define_gsubr ("set-statusbar-message", 1, 0, 0,
                       scm_set_statusbar_message);
-  scm_c_define_gsubr ("set-surface-layout", 1, 0, 0, scm_set_surface_layout);
   scm_c_define_gsubr ("reset-surface", 0, 0, 0, scm_reset_surface);
-  scm_c_define_gsubr ("add-slot", 1, 0, 0, ar_scm_add_slot);
+  scm_c_define_gsubr ("add-slot", 1, 0, 0, cscmi_add_slot);
   scm_c_define_gsubr ("get-slot", 1, 0, 0, scm_get_slot);
   scm_c_define_gsubr ("set-cards-c!", 2, 0, 0, scm_set_cards);
   scm_c_define_gsubr ("set-slot-y-expansion!", 2, 0, 0,
@@ -1206,7 +1189,7 @@ aisleriot_game_class_init (AisleriotGameClass *klass)
   gobject_class->get_property = aisleriot_game_get_property;
 
   signals[GAME_TYPE] =
-    g_signal_newv ("game-type",
+    g_signal_newv (I_("game-type"),
                    G_OBJECT_CLASS_TYPE (gobject_class),
                    (GSignalFlags) (G_SIGNAL_RUN_LAST),
                    NULL,
@@ -1216,7 +1199,7 @@ aisleriot_game_class_init (AisleriotGameClass *klass)
                    0, NULL);
 
   signals[GAME_CLEARED] =
-    g_signal_newv ("game-cleared",
+    g_signal_newv (I_("game-cleared"),
                    G_OBJECT_CLASS_TYPE (gobject_class),
                    (GSignalFlags) (G_SIGNAL_RUN_LAST),
                    NULL,
@@ -1226,7 +1209,7 @@ aisleriot_game_class_init (AisleriotGameClass *klass)
                    0, NULL);
 
   signals[GAME_NEW] =
-    g_signal_newv ("game-new",
+    g_signal_newv (I_("game-new"),
                    G_OBJECT_CLASS_TYPE (gobject_class),
                    (GSignalFlags) (G_SIGNAL_RUN_LAST),
                    NULL,
@@ -1236,7 +1219,7 @@ aisleriot_game_class_init (AisleriotGameClass *klass)
                    0, NULL);
 
   signals[SLOT_CHANGED] =
-    g_signal_newv ("slot-changed",
+    g_signal_newv (I_("slot-changed"),
                    G_OBJECT_CLASS_TYPE (gobject_class),
                    (GSignalFlags) (G_SIGNAL_RUN_LAST),
                    NULL,
@@ -1246,7 +1229,7 @@ aisleriot_game_class_init (AisleriotGameClass *klass)
                    1, ptr_types);
 
  signals[GAME_MESSAGE] =
-    g_signal_newv ("message",
+    g_signal_newv (I_("message"),
                    G_OBJECT_CLASS_TYPE (gobject_class),
                    (GSignalFlags) (G_SIGNAL_RUN_LAST),
                    NULL,
@@ -1256,7 +1239,7 @@ aisleriot_game_class_init (AisleriotGameClass *klass)
                    1, param_types);
 
  signals[EXCEPTION] =
-    g_signal_newv ("exception",
+    g_signal_newv (I_("exception"),
                    G_OBJECT_CLASS_TYPE (gobject_class),
                    (GSignalFlags) (G_SIGNAL_RUN_LAST),
                    NULL,
@@ -2054,7 +2037,7 @@ aisleriot_game_set_click_to_move (AisleriotGame *game,
 void
 aisleriot_game_generate_exception (AisleriotGame *game)
 {
-  cscmi_eval_string ("(how-about-a-nice-crash?)");
+  cscmi_eval_string ("(/ 1 0)");
 }
 
 /**
@@ -2068,6 +2051,9 @@ aisleriot_game_generate_exception (AisleriotGame *game)
 void
 aisleriot_game_deal_cards (AisleriotGame *game)
 {
+  /* If the game hasn't started yet, start it now */
+  aisleriot_game_start (game);
+
   aisleriot_game_record_move (game, -1, NULL, 0);
 
   cscmi_eval_string ("(do-deal-next-cards)");
