@@ -32,7 +32,7 @@ class GtkNetworkGameDialog(glchess.ui.NetworkController):
         
         self.profileModel = gtk.ListStore(gobject.TYPE_PYOBJECT, str)
         iter = self.profileModel.append()
-        self.profileModel.set(iter, 0, None, 1, 'Disconnected')
+        self.profileModel.set(iter, 0, None, 1, _('Disconnected'))
         
         widget = self.__gui.get_widget('server_combo')
         widget.set_model(self.profileModel)
@@ -158,6 +158,7 @@ class GtkNetworkGameDialog(glchess.ui.NetworkController):
             gobject.source_remove(self._throbberTimer)
             self._throbberTimer = None
         
+        # Display animating frames if busy or idle frame if not
         if isBusy:
             self._throbberFrame = 1
             self._throbberTimer = gobject.timeout_add(25, self._updateThrobber)
@@ -190,7 +191,7 @@ class GtkNetworkGameDialog(glchess.ui.NetworkController):
 
         self.roomIters[room] = iter
         self.roomModel.set(iter, 0, room, 1, index, 2, name, 3, nPlayers, 4, description, 5, pango.WEIGHT_NORMAL, 6, style, 7, icon)
-        
+
     def enterRoom(self, room):
         """Called by glchess.ui.UIController"""
         for (r, iter) in self.roomIters.iteritems():
@@ -324,6 +325,10 @@ class GtkNetworkGameDialog(glchess.ui.NetworkController):
         if atBottom:
             view.scroll_mark_onscreen(mark)
 
+    def clearText(self):
+        buffer = self.__gui.get_widget('chat_textview').get_buffer()
+        buffer.delete(buffer.get_start_iter(), buffer.get_end_iter())
+
     def close(self):
         """Called by glchess.ui.UIController"""
         self.__gui.get_widget('network_game_dialog').hide()        
@@ -334,19 +339,38 @@ class GtkNetworkGameDialog(glchess.ui.NetworkController):
         self._throbberTimer = None
         theme = gtk.icon_theme_get_default()
         size = 32
-        icon = theme.load_icon('process-working', size, 0)      
         self._throbberFrames = []
-        for i in xrange(icon.get_height() / size):
-            for j in xrange(icon.get_width() / size):
-                frame = icon.subpixbuf(j * size, i * size, size, size)
-                self._throbberFrames.append(frame)
         
+        icon = theme.load_icon('process-idle', size, 0)
+        if icon is not None:
+            self._throbberFrames.append(icon)
+
+        icon = theme.load_icon('process-working', size, 0)
+        if icon is not None:
+            # If a smaller icon was received than expected then use that size
+            height = icon.get_height()
+            width = icon.get_width()
+            size = min(size, height, width)
+
+            for i in xrange(height / size):
+                for j in xrange(width / size):
+                    frame = icon.subpixbuf(j * size, i * size, size, size)
+                    self._throbberFrames.append(frame)
+                
+        # Display idle frame
         self._throbberFrame = 0
         self._updateThrobber()
 
     def _updateThrobber(self):
         widget = self.__gui.get_widget('throbber_image')
-        widget.set_from_pixbuf(self._throbberFrames[self._throbberFrame])
+        try:
+            icon = self._throbberFrames[self._throbberFrame]
+        except IndexError:
+            pass
+        else:
+            widget.set_from_pixbuf(icon)
+        
+        # Move to next frame restarting animation after idle frame
         self._throbberFrame += 1
         if self._throbberFrame >= len(self._throbberFrames):
             self._throbberFrame = 1
