@@ -40,8 +40,6 @@ class ChessPiece(glchess.scene.ChessPiece):
     # Delete once moved to location
     delete      = False
     
-    deleted     = False
-    
     def __init__(self, scene, name, coord, feedback):
         """
         """
@@ -61,7 +59,6 @@ class ChessPiece(glchess.scene.ChessPiece):
 
     def move(self, coord, delete, animate = True):
         """Extends glchess.scene.ChessPiece"""
-        assert(self.deleted is False)
         self.coord = coord
         self.delete = delete
         self.targetPos = self.__coordToLocation(coord)
@@ -74,15 +71,15 @@ class ChessPiece(glchess.scene.ChessPiece):
         
         # If already there then check for deletion
         if self.pos == self.targetPos:
+            self.targetPos = None
             if delete:
-                self.deleted = True
                 self.scene.pieces.remove(self)
                 self.feedback.onDeleted()
             if redraw:
                 self.scene.redrawStatic = True
                 self.scene.feedback.onRedraw()
             return
-        
+
         # If not currently moving then start
         if not self.moving:
             self.scene._animationQueue.append(self)
@@ -101,19 +98,12 @@ class ChessPiece(glchess.scene.ChessPiece):
         
         Return True if the piece has moved otherwise False.
         """
-        # FIXME
-        if self.deleted:
-            return False
-        assert(self.deleted is False)
-        #end FIXME
-        
         if self.targetPos is None:
             return False
         
         if self.pos == self.targetPos:
             self.targetPos = None
             if self.delete:
-                self.deleted = True
                 self.scene.pieces.remove(self)
                 self.feedback.onDeleted()
             return False
@@ -376,9 +366,9 @@ class Scene(glchess.scene.Scene):
             context.set_source_rgb(*NUMBERING_COLOUR)
             context.set_font_size(self.squareSize * 0.4)
             context.select_font_face("sans-serif", cairo.FONT_SLANT_NORMAL, cairo.FONT_WEIGHT_BOLD)
-	    # Chess board columns (files) label marked for translation. 
+	    # Chess board columns (files) label marked for translation. Please translate to the first eight letters of your alphabet, or the most appropriate eight characters/symbols for labelling the columns of a chess board. 
             files = [_('a'), _('b'), _('c'), _('d'), _('e'), _('f'), _('g'), _('h')]
-	    # Chess board rows (ranks) label marked for translation.
+	    # Chess board rows (ranks) label marked for translation. Please translate to the first eight numbers with your native number symbols, or the most appropriate eight numbers/symbols for labelling the rows of a chess board.
             ranks = [_('8'), _('7'), _('6'), _('5'), _('4'), _('3'), _('2'), _('1')]
             def drawCenteredText(x, y, text):
                 (_, _, w, h, _, _) = context.text_extents('b')
