@@ -172,6 +172,9 @@ class NumberBox (gtk.Widget):
         self.set_state(gtk.STATE_NORMAL)
         self.base_state = gtk.STATE_NORMAL
         self.number_picker_mode = False
+        if hasattr(self,'npicker') and self.npicker:
+            self.npicker.destroy()
+            self.npicker = None
 
     def motion_notify_cb (self, *args):
         if self.is_focus():
@@ -297,22 +300,11 @@ class NumberBox (gtk.Widget):
     def show_number_picker (self):
         #self.number_picker_mode = True
         #return
-
-        # This should be gtk.WINDOW_POPUP - the current implementation is abusing too many hints
-        # and has problems with non-focus operations (i.e. hiding the main window).
-        # YOU should rewrite this. Yes, you the reader :)
-        w = gtk.Window()
-        w.set_transient_for(self.get_toplevel())
-        w.set_app_paintable(True)
-        w.set_property('skip-pager-hint', True)
-        w.set_property('skip-taskbar-hint', True)
-        w.set_decorated(False)
+        w = gtk.Window(type=gtk.WINDOW_POPUP)
         ns = NumberSelector(upper=self.upper,default=self.get_value())
         ns.connect('changed', self.number_changed_cb, w)
         w.grab_focus()
-        w.connect('focus-out-event',lambda w, ev: w.destroy())
         w.add(ns)
-        w.show()
         r = w.get_allocation()
         my_origin = self.window.get_origin()
         x,y = self.window.get_size()
@@ -1114,11 +1106,13 @@ class SudokuGameDisplay (SudokuNumberGrid, gobject.GObject):
 
         To specify NO trackers, use trackers=[-1]
         """
+        # Add the value to the UI to display
         self.__entries__[(x,y)].set_value(val)
         if self.doing_initial_setup:
             self.__entries__[(x,y)].set_read_only(True)
-        self.grid.add(x,y,val,True)
+        # Handle any trackers.
         if trackers:
+            # Explicitly specified tracker
             for tracker in trackers:
                 if tracker==-1: pass
                 self.__entries__[(x,y)].set_color(self.get_tracker_color(tracker))
@@ -1128,6 +1122,11 @@ class SudokuGameDisplay (SudokuNumberGrid, gobject.GObject):
                 if v:
                     self.__entries__[(x,y)].set_color(self.get_tracker_color(k))
                     self.trackers[k].append((x,y,val))
+        # Add value to our underlying sudoku grid -- this will raise
+        # an error if the value is out of bounds with the current
+        # rules. 
+        self.grid.add(x,y,val,True)
+        # Draw our entry
         self.__entries__[(x,y)].queue_draw()
 
     @simple_debug
@@ -1280,6 +1279,118 @@ class SudokuGameDisplay (SudokuNumberGrid, gobject.GObject):
         if not val: val = self.grid._get_(x,y)
         self.trackers[tracker].remove((x,y,val))
 
+class GridDancer:
+
+    DANCE_COLORS = [colors.color_hex_to_float(hx) for hx in 
+                    [
+
+        '#cc0000', # red
+        '#ef2929',
+        '#f57900', # orange
+        '#fcaf3e',
+        #'#edd400', # yellow
+        '#fce94f',
+        '#8ae234', # green
+        '#73d216',
+        '#729fcf', # blue
+        '#3465a4',
+        '#ad7fa8', # violet
+        '#75507b', ]
+                    ]
+
+    STEPS_PER_ANIMATION = 10
+    
+    def __init__ (self, grid):
+        self.animations = [self.value_dance,
+                           self.box_dance,
+                           self.col_dance,
+                           self.row_dance,]
+        self.current_animation = self.value_dance
+        self.step = 0
+        self.grid = grid
+        self.dancing = False
+        for box in self.grid.__entries__.values():
+            box.read_only = False
+            box.queue_draw()
+
+    def start_dancing (self):
+        self.dancing = True
+        gobject.timeout_add(350,self.dance_grid)
+
+    def stop_dancing (self):
+        self.dancing = False
+        print 'unhighlight_cells'
+        self.grid.unhighlight_cells()
+
+    def do_dance_step (self):
+        self.grid.__entries__[(random.randint(0,8),
+                               random.randint(0,8))
+                              ].set_background_color(
+            random.choice(self.DANCE_COLORS)
+            )
+    
+    def rotate_animation (self):
+        ci = self.animations.index(self.current_animation)
+        if (ci+1) == len(self.animations):
+            ni = 0
+        else:
+            ni = ci + 1
+        self.current_animation = self.animations[ni]
+        self.step = 0
+
+    def dance_grid (self):
+        if not self.dancing: return
+        if self.step > self.STEPS_PER_ANIMATION:
+            self.rotate_animation()
+        if hasattr(self,'adjustment'):
+            self.adjustment += 1
+        else:
+            self.adjustment = 0
+        if self.adjustment >= 9: self.adjustment = 0
+        try:
+            self.current_animation()
+        except AttributeError:
+            return True
+        self.step += 1
+        if self.dancing:
+            return True
+
+    def col_dance (self):
+        for x in range(9):
+            n = (x + self.adjustment) % len(self.DANCE_COLORS)
+            color = self.DANCE_COLORS[n]
+            for y in range(9):
+                self.grid.__entries__[(x,y)].set_background_color(color)
+                
+    def row_dance (self):
+        for y in range(9):
+            n = (y + self.adjustment) % len(self.DANCE_COLORS)
+            color = self.DANCE_COLORS[n]
+            for x in range(9):
+                self.grid.__entries__[(x,y)].set_background_color(color)
+
+    def box_dance (self):
+        for box in range(9):
+            n = (box + self.adjustment) % len(self.DANCE_COLORS)
+            color = self.DANCE_COLORS[n]
+            for x,y in self.grid.grid.box_coords[box]:
+                self.grid.__entries__[(x,y)].set_background_color(color)
+        
+    def value_dance (self):
+        for value in range(10):
+            n = (value + self.adjustment) % len(self.DANCE_COLORS)
+            color = self.DANCE_COLORS[n]
+            for x in range(9):
+                for y in range(9):
+                    if self.grid.grid._get_(x,y)==value:
+                        self.grid.__entries__[(x,y)].set_background_color(color)
+
+def test_dance_grid (grid):
+    dancer = GridDancer(grid)
+    dancer.start_dancing()
+    def stop (*args): dancer.stop_dancing()
+    gobject.timeout_add(15000,stop)
+
 if __name__ == '__main__':
     def test_sng ():
         w = gtk.Window()
@@ -1303,6 +1414,38 @@ if __name__ == '__main__':
         w.show_all()
         gtk.main()
 
+    def reproduce_foobared_rendering ():
+        from sudoku import SudokuGrid, sample_open_sudoku
+        from dialog_swallower import SwappableArea
+        sgd = SudokuGameDisplay()
+        sgd.set_bg_color('black')
+        w = gtk.Window()
+        w.connect('delete-event', gtk.main_quit)
+        vb = gtk.VBox()
+        hb = gtk.HBox()
+        swallower = SwappableArea(hb)        
+        tb = gtk.Toolbar()
+        b = gtk.ToolButton(stock_id=gtk.STOCK_QUIT)
+        b.connect('clicked',lambda x: w.hide() or gtk.main_quit())
+        tb.add(b)
+        def run_swallowed_dialog (*args):
+            md = MessageDialog(title="Bar",label="Bar",sublabel="Baz "*12)
+            swallower.run_dialog(md)
+        b2 = gtk.ToolButton(label='Dialog')
+        b2.connect('clicked',run_swallowed_dialog)
+        tb.add(b2)
+        vb.pack_start(tb,fill=False,expand=False)
+        vb.pack_start(swallower,padding=12)
+        w.add(vb)
+        w.show_all()
+        #test_dance_grid(sgd)
+        from gtk_goodies.dialog_extras import MessageDialog
+        md = MessageDialog(title="Foo",label="Foo",sublabel="Bar "*12)
+        swallower.run_dialog(md)
+        hb.pack_start(sgd,padding=6)        
+        sgd.change_grid(SudokuGrid(sample_open_sudoku),9)
+        gtk.main()        
+
     def test_sudoku_game ():
         from sudoku import SudokuGrid, sample_open_sudoku
         sgd = SudokuGameDisplay(grid=SudokuGrid(sample_open_sudoku))
@@ -1311,6 +1454,7 @@ if __name__ == '__main__':
         w.connect('delete-event', gtk.main_quit)
         w.add(sgd)
         w.show_all()
+        test_dance_grid(sgd)
         gtk.main()
         
     def test_number_selector ():
@@ -1322,11 +1466,11 @@ if __name__ == '__main__':
         w.add(ns)
         w.show_all()
         gtk.main()
-        
 
     #test_number_selector()
     #test_sng()
-    test_sudoku_game()
+    #test_sudoku_game()
+    reproduce_foobared_rendering()
 
         
             
