@@ -163,7 +163,13 @@ class UI (gconf_wrapper.GConfWrapper):
                      }    
 
     @simple_debug
-    def __init__ (self):
+    def __init__ (self, run_selector=True):
+        """run_selector means that we start our regular game.
+
+        For testing purposes, it will be convenient to hand a
+        run_selector=False to this method to avoid running the dialog
+        and allow a tester to set up a game programmatically.
+        """
         gconf_wrapper.GConfWrapper.__init__(self,
                                             gconf_wrapper.GConf('gnome-sudoku')
                                             )
@@ -189,16 +195,18 @@ class UI (gconf_wrapper.GConfWrapper):
         # generate puzzles while our use is working...        
         self.show()
         #print 'Select game!'
-        if self.select_game():
-            # If this return True, the user closed...
-            #print 'select game returned True - exit'
-            self.quit = True
-        else:
-            self.quit = False
-            # Generate puzzles in background...
-            if self.gconf['generate_puzzles_in_background']:
-                gobject.timeout_add(1000,lambda *args: self.start_worker_thread() and True)
-                
+        if run_selector:
+            self.do_stop()
+            if self.select_game():
+                # If this return True, the user closed...
+                #print 'select game returned True - exit'                
+                self.quit = True
+            else:
+                self.quit = False
+                # Generate puzzles in background...
+                if self.gconf['generate_puzzles_in_background']:
+                    gobject.timeout_add(1000,lambda *args: self.start_worker_thread() and True)
+        
 
     @inactivate_new_game_etc
     def select_game (self):
@@ -470,6 +478,9 @@ class UI (gconf_wrapper.GConfWrapper):
             sublabel += ngettext("You used the auto-fill %(n)s time",
                                  "You used the auto-fill %(n)s times",
                                  self.gsd.auto_fills)%{'n':self.gsd.auto_fills}
+        from gsudoku import GridDancer
+        self.dancer = GridDancer(self.gsd)
+        self.dancer.start_dancing()            
         dialog_extras.show_message(_("You win!"),label=_("You win!"),
                                    #icon=os.path.join(IMAGE_DIR,'winner2.png'),
                                    sublabel=sublabel
@@ -483,7 +494,7 @@ class UI (gconf_wrapper.GConfWrapper):
         #hs.run_dialog()
         #self.main_actions.get_action('HighScores').set_sensitive(True)
         #self.gsd.blank_grid()
-        self.new_cb()
+        #self.new_cb()
 
     @simple_debug
     def initialize_prefs (self):
@@ -527,6 +538,9 @@ class UI (gconf_wrapper.GConfWrapper):
             self.do_stop()
             
     def do_stop (self):
+        if hasattr(self,'dancer'):
+            self.dancer.stop_dancing()
+            delattr(self,'dancer')
         self.gsd.grid = None
         self.tracker_ui.reset()
         self.timer.reset_timer()
@@ -841,6 +855,7 @@ class UI (gconf_wrapper.GConfWrapper):
     @simple_debug
     def show_about (self, *args):
         about = gtk.AboutDialog()
+        about.set_transient_for(self.w)
         about.set_name(APPNAME)
         about.set_version(VERSION)
         about.set_copyright(COPYRIGHT)
@@ -870,7 +885,7 @@ class UI (gconf_wrapper.GConfWrapper):
 
     @simple_debug
     def print_multiple_games (self, *args):
-        gp=game_selector.GamePrinter(self.sudoku_tracker, self.gconf)
+        gp=game_selector.GamePrinter(self.sudoku_maker, self.gconf)
         gp.run_dialog()
 
     @simple_debug
