@@ -43,7 +43,7 @@
 #include <math.h>
 
 int LINES = 20;
-int COLUMNS = 11;
+int COLUMNS = 14;
 
 int BLOCK_SIZE = 40;
 
@@ -53,13 +53,14 @@ int color_next = -1;
 
 bool random_block_colors = false;
 bool do_preview = true;
+bool default_bgimage = false;
 bool rotateCounterClockWise = true;
 
 #define TETRIS_OBJECT "gnometris-tetris-object"
 
 #define TILE_THRESHOLD 65
 
-#define DEFAULT_WIDTH 440
+#define DEFAULT_WIDTH 500
 #define DEFAULT_HEIGHT 550
 
 enum {
@@ -146,6 +147,14 @@ Tetris::Tetris(int cmdlLevel):
 	    mkdir (outdir, 0700);
 	bgPixmap = g_build_filename (outdir, "background.bin", NULL);
 	g_free (outdir);
+
+	/*  Use default background image, if none found in user's home dir.*/
+	if (!g_file_test (bgPixmap, G_FILE_TEST_EXISTS)) {
+          defaultPixmap = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_APP_DATADIR,
+					        "pixmaps/gnometris/gnometris.svg",
+						 TRUE, NULL);
+	  default_bgimage = true;
+	}
 	
 	w = gnome_app_new("gnometris", _("Gnometris"));
 	g_signal_connect (w, "delete_event", G_CALLBACK (gameQuit), this);
@@ -260,6 +269,8 @@ Tetris::~Tetris()
 
 	if (bgPixmap)
 		g_free(bgPixmap);
+	if (defaultPixmap)
+		g_free(defaultPixmap);
 
         if (confNotifyID != 0)
                 g_signal_handler_disconnect (games_conf_get_default (), confNotifyID);
@@ -304,13 +315,15 @@ Tetris::setupPixmap()
 	else {
 		if (g_file_test (bgPixmap, G_FILE_TEST_EXISTS)) 
 			bgimage = gdk_pixbuf_new_from_file (bgPixmap, NULL);
+		else if (g_file_test (defaultPixmap, G_FILE_TEST_EXISTS)) 
+			bgimage = gdk_pixbuf_new_from_file (defaultPixmap, NULL);
 		else 
 			bgimage = NULL;
 	}
 
 	/* A nasty hack to tile the image if it looks tileable (i.e. it
 	 * is small enough. */
-	if (bgimage) {
+	if (bgimage && !default_bgimage) {
 		int width, height;
 		int bgwidth, bgheight;
 			
@@ -457,7 +470,7 @@ Tetris::initOptions ()
 	gdk_color_parse (bgcolourstr, &bgcolour);
 	g_free (bgcolourstr);
 
-	usebg = confGetBoolean (KEY_OPTIONS_GROUP, KEY_USE_BG_IMAGE, FALSE);
+	usebg = confGetBoolean (KEY_OPTIONS_GROUP, KEY_USE_BG_IMAGE, TRUE);
 }
 
 void
@@ -1381,11 +1394,10 @@ Tetris::gameAbout(GtkAction *action, void *d)
 			       "name", _("Gnometris"),
 #endif
 			       "version", VERSION,
-			       "comments", _("Written for my wife, Matylda\n"
-					     "Send comments and bug reports to: \n"
-					     "janusz.gorycki@intel.com"),
-			       "copyright", "Copyright \xc2\xa9 1999-2007 J. Marcin Gorycki",
+			       "comments", _("A classic game of fitting falling blocks together.\n\nGnometris is a part of GNOME Games."),
+			       "copyright", "Copyright \xc2\xa9 1999-2008 J. Marcin Gorycki",
 			       "license", license,
+		               "website-label", _("GNOME Games web site"),
 			       "authors", authors,
 			       "documenters", documenters,				
 			       "translator-credits", _("translator-credits"),
