@@ -20,7 +20,6 @@
 
 #include "config.h"
 #include <gnome.h>
-#include <gconf/gconf-client.h>
 #include <pwd.h>
 
 #include <ggzmod.h>
@@ -309,7 +308,8 @@ on_network_game (void)
 
   ggz_gtk_initialize (FALSE,
 		      ggz_connected, ggz_game_launched, ggz_closed,
-		      NETWORK_ENGINE, NETWORK_VERSION, "GNOME GGZ");
+		      NETWORK_ENGINE, NETWORK_VERSION, "iagno.xml",
+		      "GGZ Gaming Zone");
 
   pwent = getpwuid(getuid());
 
